// ---------------------------------------------------------------------------
// third_person.cs -- Version 1.3 -- October 27, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Automatically switch to third-person view while moving in certain directions, and
// trigger events on point of view changes (from 1st person to 3rd person, etc.)
//
// Based on a cool little script by Avox :)
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\third_person.cs", "1.3", "Lorne Laliberte", "Oct 27, 2000");

include("writer\\event.cs");
include("writer\\inventory.cs");
include("writer\\move.cs");
include("writer\\save.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_third_person.cs file

    // Switch to third-person view when you move in that direction while in
    // Pilot Mode
    $ThirdPerson::PilotMode::Forward = "false";
    $ThirdPerson::PilotMode::Back    = "true";
    $ThirdPerson::PilotMode::Left    = "true";
    $ThirdPerson::PilotMode::Right   = "true";

    // Switch to third-person view when you move in that direction
    $ThirdPerson::Forward = "false";
    $ThirdPerson::Back    = "false";
    $ThirdPerson::Left    = "false";
    $ThirdPerson::Right   = "false";

    // Don't switch to third person if you're using these weapons
    ThirdPerson::noThirdUsing("Laser Rifle");
    ThirdPerson::noThirdUsing("Sniper Rifle");

    // IMPORTANT: make sure you bind your "external view" key below

    // Press key to toggle third person view on/off
    //bind(keyboard0, make, "f12", to, "ThirdPerson::toggle();");
    //bind(keyboard0, break, "f12", to, "", "ThirdPerson::toggle_break");

// ---------------------------------------------------------------------------

WriterPrefs::load("third_person");

$ThirdPerson::PilotModeToggle = true;
$ThirdPerson::Toggle          = true;


function ThirdPerson::on(%move)
{
    if($ThirdPerson)
        return;

    if($PilotMode)
        %pilotMode = "PilotMode::";

    if($ThirdPerson::[%pilotmode @ %move])
    {
        if($ThirdPerson::noThirdUsing[$Inv::Name[getMountedItem(0)]])
            return;

        $ThirdPerson = true;
    	postAction(2048, IDACTION_VIEW, 0);

        Event::Trigger(eventThirdPerson);
    }
    return;
}


function ThirdPerson::off(%move)
{
    if($ThirdPerson && !$ThirdPerson::override)
    {
        if($PilotMode)
            %pilotMode = "PilotMode::";

        if($ThirdPerson::[%pilotmode @ %move])
        {
            $ThirdPerson = false;
        	postAction (2048, IDACTION_VIEW, 0);

            Event::Trigger(eventFirstPerson);
        }
    }
    return;
}


function ThirdPerson::toggle()
{
    $ThirdPerson::override = $ThirdPerson = !$ThirdPerson;

	postAction (2048, IDACTION_VIEW, 0);

    if($ThirdPerson)
        Event::Trigger(eventThirdPerson);
    else
        Event::Trigger(eventFirstPerson);
}

function third_person::save()
{
    AddExportText("    // Switch to third-person view when you move in that direction while in");
    AddExportText("    // Pilot Mode");
    ExportSetting("    $ThirdPerson::PilotMode::Forward", false);
    ExportSetting("    $ThirdPerson::PilotMode::Back   ", true);
    ExportSetting("    $ThirdPerson::PilotMode::Left   ", true);
    ExportSetting("    $ThirdPerson::PilotMode::Right  ", true);
    AddExportText("");
    AddExportText("    // Switch to third-person view when you move in that direction");
    ExportSetting("    $ThirdPerson::Forward", false);
    ExportSetting("    $ThirdPerson::Back   ", false);
    ExportSetting("    $ThirdPerson::Left   ", false);
    ExportSetting("    $ThirdPerson::Right  ", false);
    AddExportText("");
    AddExportText("    // Don't switch to third person if you're using these weapons");

    if(!ExportIndexed("    ThirdPerson::noThirdUsing(%1);", "$ThirdPerson::noThirdUsing[%1]", "$ThirdPerson::noThirdUsing::index[%1]", 1, $ThirdPerson::noThirdUsing::count))
    {
        AddExportText("    ThirdPerson::noThirdUsing(\"Laser Rifle\");");
        AddExportText("    ThirdPerson::noThirdUsing(\"Sniper Rifle\");");
    }

    AddExportText("");
    AddExportText("    // IMPORTANT: make sure you bind your \"external view\" key below");
    AddExportText("");
    AddExportText("    // Press key to toggle third person view on/off");

    ExportBind("ThirdPerson::toggle();", "//bind(keyboard0, make, \"f12\", TO, \"ThirdPerson::toggle();\");");
    ExportBind("ThirdPerson::toggle_break", "//bind(keyboard0, break, \"f12\", TO, \"\", ThirdPerson::toggle_break);");
}

WriterPrefs::save("third_person");

function third_person::init()
{
    needs("writer\\third_person.cs", "writer\\event.cs 2.7",
                                     "writer\\inventory.cs 3.3",
                                     "writer\\move.cs 1.3",
                                     "writer\\save.cs 2.3");

    if($ThirdPerson::PilotMode::Forward || $ThirdPerson::Forward)
    {
        Event::Attach(eventForwardStarted, "ThirdPerson::on(\"Forward\");");
        Event::Attach(eventForwardStopped, "ThirdPerson::off(\"Forward\");");
    }

    if($ThirdPerson::PilotMode::Back || $ThirdPerson::Back)
    {
        Event::Attach(eventBackStarted, "ThirdPerson::on(\"Back\");");
        Event::Attach(eventBackStopped, "ThirdPerson::off(\"Back\");");
    }

    if($ThirdPerson::PilotMode::Left || $ThirdPerson::Left)
    {
        Event::Attach(eventLeftStarted, "ThirdPerson::on(\"Left\");");
        Event::Attach(eventLeftStopped, "ThirdPerson::off(\"Left\");");
    }

    if($ThirdPerson::PilotMode::Right || $ThirdPerson::Right)
    {
        Event::Attach(eventRightStarted, "ThirdPerson::on(\"Right\");");
        Event::Attach(eventRightStopped, "ThirdPerson::off(\"Right\");");
    }
}
Event::Attach(writerInit, "third_person::init();");

if(!$UsingWriterLoader) third_person::init();
